==> knowledge_repo-0.8.8.tar.gz: knowledge_repo-0.8.8/README.md <==
# Knowledge Repo

[![PyPI](https://img.shields.io/pypi/status/knowledge-repo.svg)]()
[![license](https://img.shields.io/github/license/airbnb/knowledge-repo.svg)]()
[![PyPI version](https://badge.fury.io/py/knowledge-repo.svg)](https://badge.fury.io/py/knowledge-repo)
[![Python](https://img.shields.io/pypi/pyversions/knowledge-repo.svg?maxAge=2592000)](https://pypi.python.org/pypi/knowledge-repo)
[![Build Status](https://travis-ci.org/airbnb/knowledge-repo.svg?branch=master)](https://travis-ci.org/airbnb/knowledge-repo)
[![Windows Build Status](https://ci.appveyor.com/api/projects/status/t88a27n099oqnbsw/branch/master?svg=true&pendingText=Windows%20build%20pending...&passingText=Windows%20build%20passing&failingText=Windows%20build%20failing)](https://ci.appveyor.com/project/matthewwardrop/knowledge-repo)

The Knowledge Repo project is focused on facilitating the sharing of
knowledge between data scientists and other technical roles using data formats
and tools that make sense in these professions. It provides various data stores
(and utilities to manage them) for "knowledge posts", with a particular focus on
notebooks (R Markdown and Jupyter / IPython Notebook) to better promote
reproducible research.

For more information about the motivation and inspiration behind this project, we encourage you to read our [Medium Post](https://medium.com/airbnb-engineering/scaling-knowledge-at-airbnb-875d73eff091).

- **Documentation:** http://knowledge-repo.readthedocs.io
- **Source:** https://github.com/airbnb/knowledge-repo
- **Bug reports**: https://github.com/airbnb/knowledge-repo/issues

## Screenshots

![Main Feed](https://user-images.githubusercontent.com/124910/37555895-d6ad133a-2a42-11e8-9bb5-1b7ee8d60ef9.png)

![Example Post](https://user-images.githubusercontent.com/124910/37555894-d662eb5c-2a42-11e8-9547-78bef7835521.png)

==> knowledge_repo-0.9.0.tar.gz: knowledge_repo-0.9.0/README.md <==
# Knowledge Repo

[![PyPI](https://img.shields.io/pypi/status/knowledge-repo.svg)]()
[![license](https://img.shields.io/github/license/airbnb/knowledge-repo.svg)]()
[![PyPI version](https://badge.fury.io/py/knowledge-repo.svg)](https://badge.fury.io/py/knowledge-repo)
[![Python](https://img.shields.io/pypi/pyversions/knowledge-repo.svg?maxAge=2592000)](https://pypi.python.org/pypi/knowledge-repo)
[![Build Status](https://travis-ci.org/airbnb/knowledge-repo.svg?branch=master)](https://travis-ci.org/airbnb/knowledge-repo)
[![Windows Build Status](https://ci.appveyor.com/api/projects/status/t88a27n099oqnbsw/branch/master?svg=true&pendingText=Windows%20build%20pending...&passingText=Windows%20build%20passing&failingText=Windows%20build%20failing)](https://ci.appveyor.com/project/matthewwardrop/knowledge-repo)

The Knowledge Repo project is focused on facilitating the sharing of
knowledge between data scientists and other technical roles using data formats
and tools that make sense in these professions. It provides various data stores
(and utilities to manage them) for "knowledge posts", with a particular focus on
notebooks (R Markdown and Jupyter / IPython Notebook) to better promote
reproducible research.

For more information about the motivation and inspiration behind this project, we encourage you to read our [Medium Post](https://medium.com/airbnb-engineering/scaling-knowledge-at-airbnb-875d73eff091).

- **Documentation:** http://knowledge-repo.readthedocs.io
- **Source:** https://github.com/airbnb/knowledge-repo
- **Bug reports**: https://github.com/airbnb/knowledge-repo/issues

## Screenshots

![feed](https://user-images.githubusercontent.com/8813413/83345201-451ce500-a2c5-11ea-8eb9-1fbeda22b213.png)

![post_example](https://user-images.githubusercontent.com/8813413/83345203-48b06c00-a2c5-11ea-8edb-18e7f8f157ce.png)

![new_post](https://user-images.githubusercontent.com/8813413/83345202-4817d580-a2c5-11ea-9f75-964980c4c3c3.png)

![post_form](https://user-images.githubusercontent.com/8813413/83345204-49490280-a2c5-11ea-97e3-248192b01526.png)

![stats](https://user-images.githubusercontent.com/8813413/83345205-49490280-a2c5-11ea-9af2-2a01b69ae584.png)
